@@ -33,6 +33,7 @@
 
 
 #include "cuyointl.h"
+#include "sound.h"
 #include "aufnahme.h"
 #include "prefsdaten.h"
 #include "kiplayer.h"
@@ -129,6 +130,9 @@ Cuyo::Cuyo(QWidget*parent,const char* name):
   /* Preferences-Objekt erzeugen. Hier wird die .cuyo-Datei gelesen.
      PrefsDaten speichert sich selbst in die globale Variable gPrefs. */
   new PrefsDaten();
+    
+  /* Sound-Objekt erzeugen. Es speichert sich selbst nach gSound */
+  new Sound();
 
   /* Hier findet das parsen statt. (Fehler werden im try-catch-Block
      der main()-Routine ausgegeben.) Das LevelDaten-Objekt weist
@@ -175,6 +179,14 @@ Cuyo::Cuyo(QWidget*parent,const char* name):
     /* Titelbild erzeugen */
     try {
       ld->ladLevel(level_titel, i + 1);
+      
+      /* Titelmusik entnehmen (vom Einspielermodus ;-) */
+      if (i == 0) {
+        mTitelMusik = ld->mMusik;
+	/* Und gleich starten */
+        gSound->playMod(mTitelMusik);
+      }
+	
       mSpielfeld[i]->erzeugTitelbild();
     } catch (Fehler f) {
       fprintf(stderr, _("Could not load Title:\n"));
@@ -239,6 +251,7 @@ Cuyo::~Cuyo(){
   delete ld;
   delete mKI;
   delete gPrefs;
+  delete gSound;
 }
 
 /**  */
@@ -442,6 +455,12 @@ void Cuyo::stopSpiel(bool wegen_fehler/* = false*/) {
 
   stopLevel(true, wegen_fehler);
 
+  /* Titelmusik wieder starten. */
+  //if (mGModus != gmodus_kein_spiel) {
+  gSound->playMod(mTitelMusik);
+  //}
+
+
   /* Evtl. wird das Spiel zu einem Zeitpunkt gestoppt, zu dem
      noch gar kein Timer existiert... */
   if (mTimer)	
@@ -686,7 +705,7 @@ noch_gras_da:;
 
       /* Neuen Text (mit neuer Punkt-Zahl) schreiben */
       __String s;
-      s.sprintf(_("Level %s complete!\n\nTime Bonus: %d\nScore: %d\n\n"),
+      s.sprintf(_("Level %s complete!\n\nTime Bonus: %d\nScore: %d\n\n "),
 		ld->mLevelName.data(), mZeitBonus, mPunkte[i]);
       /* Kein update-Event; bei bonusSchritt wird eh neu gemalt. */
       mSpielfeld[i]->setText(s, false);
@@ -827,6 +846,8 @@ bool Cuyo::startLevel() {
   if (mGegenKI)
     mKI->startLevel();
 
+
+  gSound->playMod(ld->mMusik);
 	
   setGModus(gmodus_spiel_start);
   mWarteAufTaste = true;
@@ -886,7 +907,7 @@ bool Cuyo::getInTime() const {
 
 
 /** Liefert die Anzahl der Mitspieler zurck. */
-bool Cuyo::getSpielerZahl() const {
+int Cuyo::getSpielerZahl() const {
   return mSpielerZahl;
 }
 
