@@ -329,6 +329,9 @@ void LevelDaten::ladLevel(int nr, int spz) {
    mStapelHoehe += mNachbarStapelHoehe;
 
 
+   /* Musik (optional) */
+   mMusik = mLevelConf->getEintrag("music", "");
+
   /***** KI-Player-Bewertungen *****/
     mKINHoehe =
       mLevelConf->getZahlEintrag("aiu_height", 10);
